<!--
https://pypi.org/project/readme-generator/
-->

[![](https://img.shields.io/pypi/pyversions/readme-generator.svg?longCache=True)](https://pypi.org/project/readme-generator/)

#### Installation
```bash
$ [sudo] pip install readme-generator
```

#### Features
+   generate README from **`<section-name>.md` sections**
+   **auto headers**
+   `readme_generator.Readme` class

#### How it works
```
<global>/badges.md          global section
<global>/headers.json       global custom headers (optional). example: {"badges":""}
<global>/order.txt          global order. section names line by line

<repo>/section-name.md      section
<repo>/order.txt            custom order     (optional)
```

`README.md`:
```markdown
<badges.md content>

#### Section-name
<section-name.md content>
```

#### Headers
**custom header**:
+   `headers.json` `{"how":"How it works"}`
+   `#### Insert Custom header in the first line`

**without header**: `headers.json` - `{"badges":""}` or empty first line/empty header

#### Examples
`README/`: `README/features.md`, `README/examples.md`, ...

```bash
$ python -m readme_generator README > README.md
```

```python
readme_generator.Readme("README").save("README.md")
```

`readme_generator.Readme` - you can load .md files and use attrs/properties/methods as sections

```python
class Readme_python(readme_generator.Readme):
    order = ["install", ..., "footer"]
    headers = {"footer":""}
    footer = "footer ..."

    def install(self):
        return "`$ [sudo] pip install %s`" % self.name
```

#### global config location

`$README_GENERATOR_HOME`, default is `$XDG_CONFIG_HOME/readme-generator`, e.g.:

`~/.config/readme-generator`

#### Related projects
+   [`classifiers-generator` - python classifiers generator](https://pypi.org/project/classifiers-generator/)
+   [`commands-generator` - shell commands generator](https://pypi.org/project/commands-generator/)
+   [`launchd-generator` - launchd.plist generator](https://pypi.org/project/launchd-generator/)
+   [`readme-badges` - `README.md` badges](https://pypi.org/project/readme-badges/)
+   [`readme-docstring` - generate README.md from python docstrings](https://pypi.org/project/readme-docstring/)
+   [`readme-generator` - `README.md` generator](https://pypi.org/project/readme-generator/)
+   [`setupcfg-generator` - `setup.cfg` generator](https://pypi.org/project/setupcfg-generator/)
+   [`travis-generator` - `.travis.yml` generator](https://pypi.org/project/travis-generator/)

<p align="center">
    <a href="https://pypi.org/project/readme-generator/">readme-generator</a>
</p>